@@ -342,8 +342,7 @@ class Stellar:
     
                  
                 WHERE b.alt_id_typ_cd = 'HIC'
-                AND EXTRACT(YEAR from b.row_eff_dt) <= 2021
-                AND EXTRACT(YEAR from b.row_expir_dt) >= 2021)
+                AND b.row_expir_dt >= '2021-11-04')
             
                 WITH DATA
                 ON COMMIT PRESERVE ROWS;
